@@ -16,7 +16,6 @@ import uuid
 from oslo_utils import timeutils
 from six.moves import range
 
-import keystone.conf
 from keystone import exception
 from keystone.federation import constants as federation_constants
 from keystone.models import token_model
@@ -24,14 +23,9 @@ from keystone.tests.unit import core
 from keystone.tests.unit import test_token_provider
 
 
-CONF = keystone.conf.CONF
-
-
 class TestKeystoneTokenModel(core.TestCase):
     def setUp(self):
         super(TestKeystoneTokenModel, self).setUp()
-        self.v2_sample_token = copy.deepcopy(
-            test_token_provider.SAMPLE_V2_TOKEN)
         self.v3_sample_token = copy.deepcopy(
             test_token_provider.SAMPLE_V3_TOKEN)
 
@@ -161,7 +155,6 @@ class TestKeystoneTokenModel(core.TestCase):
     def test_token_model_dual_scoped_token(self):
         domain = {'id': uuid.uuid4().hex,
                   'name': uuid.uuid4().hex}
-        self.v2_sample_token['access']['domain'] = domain
         self.v3_sample_token['token']['domain'] = domain
 
         self.assertRaises(exception.UnexpectedError,
